#
# spec file for package python-redfish
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2020-2025, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-redfish
Version:        3.2.8
Release:        1.1
Summary:        Redfish Python Library
License:        BSD-3-Clause
URL:            https://github.com/DMTF/python-redfish-library
Source:         https://github.com/DMTF/python-redfish-library/archive/%{version}.tar.gz#/redfish-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-jsonpatch
Requires:       python-jsonpath-rw
Requires:       python-jsonpointer
Requires:       python-requests
Requires:       python-requests-toolbelt
Requires:       python-requests-unixsocket
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module jsonpatch}
BuildRequires:  %{python_module jsonpath-rw}
BuildRequires:  %{python_module jsonpointer}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests-toolbelt}
BuildRequires:  %{python_module requests-unixsocket}
BuildRequires:  %{python_module requests}
# /SECTION
%python_subpackages

%description
The Redfish library performs the basic HTTPS operations GET, POST,
PUT, PATCH and DELETE on resources using the HATEOAS (Hypermedia as
the Engine of Application State) Redfish architecture.

%prep
%autosetup -p1 -n %{name}-library-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license LICENSE.md
%doc README.rst CHANGELOG.md
%{python_sitelib}/redfish*

%changelog
* Sun Feb  2 2025 Martin Hauke <mardnh@gmx.de>
- Update to version 3.2.8
  * Updated 'dict' handling for responses without a body and 500
    responses with a non-JSON body to use an empty dictionary.
* Tue Dec 24 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 3.2.7
  * Added JSON formatting of responses to debug logs
* Fri Nov 15 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 3.2.6
  * Added workaround for services incorrectly responding with 401
    when accessing the service root.
* Sat Sep 14 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 3.2.5
  * Added new 'check_connectivity' option when creating the
    client object.
* Sun Aug 18 2024 Dirk Müller <dmueller@suse.com>
- update to 3.2.4:
  * Removed clearing of username and password to allow for
    sessions to be re-established
* Fri Jan 26 2024 Dirk Müller <dmueller@suse.com>
- update to 3.2.2:
  * Minor changes to fix Python 3.12 warnings with usage of raw
    strings
* Fri Dec 29 2023 Dirk Müller <dmueller@suse.com>
- update to 3.2.1:
  * Added 'timeout' and 'max_retry' parameters to all REST
    methods
  * Added exception to the method when a response contains a
    message indicating a password change is required
  * Adding missing newline to M-SEARCH requests
  * Fixed the inspection of the USN response header from M-SEARCH
    requests to allow for a multi-digit minor version
  * Improved usage of the ServerDownOrUnreachableError exception
    to not lose the original message
* Wed Dec  7 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 3.1.8
  * Added request headers to debug log output
  * Added redacting of 'Password' properties from request bodies from debug logs
* Sat Oct 29 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 3.1.7:
  * Added handling for extracting error information when a session could not be created
* Fri Jun 17 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 3.1.6:
  * Fixed issue where the 'read' method on response objects always return strings
  * Modified query parameter encoding to not percent-encode characters allowed in query strings per RFC3986
* Wed Apr 13 2022 Steve Kowalik <steven.kowalik@suse.com>
- Update to 3.1.5:
  * Added methods for specifying proxies directly with a new 'proxies'
    parameter
  * Removed enforcement of trailing '/' in the 'default_prefix'
  * Added support for Unix sockets
  * Corrected usage of header storage and retrieval for static response objects
  * Corrected 'import' statements to support Python 3.10
- Drop patch collections-python310.patch, included upstream.
- Add requests-unixsocket to {Build,}Requires.
- Drop unneeded BuildRequires on mock.
* Wed Jan 19 2022 Dirk Müller <dmueller@suse.com>
- update to 3.1.0:
  * Updated library to leverage 'requests' in favor of 'http.client'
- add collections-python310.patch
* Mon Oct 25 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 3.0.3
  * Added support for performing multi-part HTTP POST requests
* Mon Aug 30 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 3.0.2
  * Added support for prepending 'https://' when the provided URI
    of the service does not contain a scheme.
- Update to version 3.0.1
  * Provided additional handling for HTTP 301 and 302 redirects.
  * Changed session creation to not follow redirects in order to
    ensure the session token and location are not lost.
  * Enhanced invalid JSON response handling to better highlight a
    service error.
- Update to version 3.0.0
  * Removed Python2 support
- Update to version 2.2.0
  * Added support for NO_PROXY environment variable
- Update to version 2.1.9
  * Added handling for HTTP 303 responses as part of redirect
    handling.
* Mon Aug 10 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.1.8
  * Added option to SSDP discover to bind to a specified address
  * Added ability to override built-in HTTP headers.
  * Fixed issue where the location of a session was not being.
    tracked properly for HTTP connections.
* Mon Jul  6 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.1.7
  * Added support for setting the 'Content-Type' header to
    'application/octet-stream' when binary data is provided in a
    request
* Sat Jun 13 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.1.6
  * Added support for leveraging the 'HTTP_PROXY' and 'HTTPS_PROXY'
    environment variables to set up proxy information
* Thu Mar 19 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to 2.1.5:
  * Removed urlparse2 dependency
  * Updated jsonpatch requirements; jsonpatch 1.25 dropped Python 3.4 support
- Dropped patch 0001-remove-urlparse2-dependncy.patch, now included
* Thu Jan 30 2020 Martin Hauke <mardnh@gmx.de>
- Initial package, version 2.1.4
- Add patch:
  * 0001-remove-urlparse2-dependncy.patch
